@@ -1,10 +1,9 @@
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-|
 Module      : HsLua.Module.Path
-Copyright   : © 2021-2022 Albert Krewinkel
+Copyright   : © 2021-2023 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <albert+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 
 Lua module to work with file paths.
 -}
@@ -33,9 +32,6 @@ module HsLua.Module.Path (
   )
 where
 
-#if !MIN_VERSION_base(4,11,0)
-import Data.Semigroup (Semigroup(..))  -- includes (<>)
-#endif
 import Data.Text (Text)
 import Data.Version (Version, makeVersion)
 import HsLua.Core
@@ -55,6 +51,7 @@ documentedModule = Module
   , moduleFields = fields
   , moduleFunctions = functions
   , moduleOperations = []
+  , moduleTypeInitializers = []
   }
 
 --
@@ -72,6 +69,7 @@ fields =
 separator :: Field e
 separator = Field
   { fieldName = "separator"
+  , fieldType = "string"
   , fieldDescription = "The character that separates directories."
   , fieldPushValue = pushString [Path.pathSeparator]
   }
@@ -80,6 +78,7 @@ separator = Field
 search_path_separator :: Field e
 search_path_separator = Field
   { fieldName = "search_path_separator"
+  , fieldType = "string"
   , fieldDescription = "The character that is used to separate the entries in "
                     <> "the `PATH` environment variable."
   , fieldPushValue = pushString [Path.searchPathSeparator]
